pub struct Params(/* private fields */);Available on crate features
audio only.Implementations
Sourceimpl Params
impl Params
Sourcepub fn set(&mut self, name: &str, value: &[u8]) -> bool
pub fn set(&mut self, name: &str, value: &[u8]) -> bool
Set param entry by name returns whether the given name was recognized
and hence updated or not
Sourcepub fn get(&self, name: &str) -> Option<&[u8]>
pub fn get(&self, name: &str) -> Option<&[u8]>
Look up parameter by name, returns None if name was not recognized
Sourcepub fn keys<'ret>(&self) -> impl Iterator<Item = &'ret str> + use<'ret>
pub fn keys<'ret>(&self) -> impl Iterator<Item = &'ret str> + use<'ret>
Return an iterator enumerating all valid parameter names
pub fn as_ptr(&self) -> *const Params
pub fn into_raw(self) -> Params