#[non_exhaustive]pub struct Notifications(/* private fields */);Implementations
Sourceimpl Notification
impl Notification
pub const Begin: Notification
pub const End: Notification
pub const IndexMarks: Notification
pub const Cancel: Notification
pub const Pause: Notification
pub const Resume: Notification
pub const All: Notification
Sourceimpl Notification
impl Notification
Sourcepub const fn empty() -> Notification
pub const fn empty() -> Notification
Get a flags value with all bits unset.
Sourcepub const fn all() -> Notification
pub const fn all() -> Notification
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Notification>
pub const fn from_bits(bits: u32) -> Option<Notification>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Notification
pub const fn from_bits_truncate(bits: u32) -> Notification
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Notification
pub const fn from_bits_retain(bits: u32) -> Notification
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Notification>
pub fn from_name(name: &str) -> Option<Notification>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Notification) -> bool
pub const fn intersects(&self, other: Notification) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Notification) -> bool
pub const fn contains(&self, other: Notification) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: Notification)
pub fn insert(&mut self, other: Notification)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: Notification)
pub fn remove(&mut self, other: Notification)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Notification)
pub fn toggle(&mut self, other: Notification)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Notification, value: bool)
pub fn set(&mut self, other: Notification, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Notification) -> Notification
pub const fn intersection(self, other: Notification) -> Notification
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Notification) -> Notification
pub const fn union(self, other: Notification) -> Notification
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Notification) -> Notification
pub const fn difference(self, other: Notification) -> Notification
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Notification) -> Notification
pub const fn symmetric_difference(self, other: Notification) -> Notification
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Notification
pub const fn complement(self) -> Notification
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Notification
impl Notification
Sourcepub const fn iter(&self) -> Iter<Notification> ⓘ
pub const fn iter(&self) -> Iter<Notification> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Notification> ⓘ
pub const fn iter_names(&self) -> IterNames<Notification> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.