CapitalLetters

Enum CapitalLetters 

#[non_exhaustive]
#[repr(C)]
pub enum CapitalLetters { None = 0, Spell = 1, Icon = 2, }
Capital letter recognition

This settings only affect consecutive runs of capital letters (eg: “SSIP”), not words starting with a single capital letter (eg: “Berlin”).

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None = 0

Captial letter blocks should be pronounced as as other words



Spell = 1

Captial letter blocks should be spelled as individual letters



Icon = 2

Captial letter blocks should have each letter prepended by the “capital” sound icon (generally a short tick sound)