#[repr(C)]pub enum Spelling {
Off = 0,
On = 1,
}Expand description
Spelling mode enabled
Informational in the context of an output module, as speech dispatcher itself will perform the transformation of regular text into indiviual character spellings.
Variants