pub enum Param {
Rate(Rate),
Pitch(Pitch),
PitchRange(PitchRange),
Volume(Volume),
PunctuationMode(Punctuation),
SpellingMode(Spelling),
CapLetRecogn(CapitalLetters),
VoiceType(VoiceType),
VoiceName(String),
Language(String),
Other(String, String),
}Expand description
Enumeration of all standard speech dispatcher properties and an other field for custom properties
See the section 4.1.6 (“Parameter Settings Commands”) of the speech-dispatcher manual for a list of client-side functions corresponding alongside their meanings.
Variants
Rate(Rate)
Speaking rate
Pitch(Pitch)
Voice baseline pitch
PitchRange(PitchRange)
Voice pitch variation range
Volume(Volume)
Voice volume or intensity
PunctuationMode(Punctuation)
Punctuation verbosity mode
SpellingMode(Spelling)
Spelling mode enabled
CapLetRecogn(CapitalLetters)
Capital letter recognition
VoiceType(VoiceType)
Symbolic voice type
VoiceName(String)
Synthesis voice name
If received from the server this should generally match one of the
names returned by your Module::list_voices function. You are not
obliged to accept unknown voice names, but may fall back to any default
choice of your choosing in such case.
Language(String)
Input text language
Semantics match those of Param::VoiceName, each voice name and
language pair should be unique. Output modules should avoid
synthesizing in the wrong language though.
Other(String, String)
Other value, generally you can reject these